@@ -11,12 +11,12 @@ use warnings::register;
 use attributes;
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.22';
-$DATE = '2004/05/11';
+$VERSION = '1.25';
+$DATE = '2004/05/20';
 $FILE = __FILE__;
 
-use Data::SecsPack 0.04;
 use Data::Startup 0.02;
+use Data::Str2Num 0.05;
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1; # dump hashes sorted
 $Data::Dumper::Terse = 1; # avoid Varn Variables
@@ -47,7 +47,6 @@ sub new
        indent => '',
        version => $VERSION,
        warnings => 0,
-       'Data::SecsPack' => {}
    );
    $self->Data::Startup::override(@_);
 
@@ -60,9 +59,7 @@ sub new
 # in the regards to interface with SecsPack
 #
 # use SelfLoader;
-
 # 1
-
 # __DATA__
 
 
@@ -252,7 +249,7 @@ sub listify
                      }
                  }
                  if($is_numeric) {
-                     ($str, my @num) = Data::SecsPack->str2float(@{$var->[$i]}, {ascii_float => 1});
+                     ($str, my @num) = Data::Str2Num->str2float(@{$var->[$i]}, {ascii_float => 1});
                      if(@num != 0 && @$str == 0) {
                          push @secs_obj, 'N', \@num;
                          $i++;
@@ -321,7 +318,7 @@ sub listify
                      ######
                      # Try for a single packed number type
                      #
-                     ($str,my @num) = Data::SecsPack->str2float($var->[$i], {ascii_float => 1});
+                     ($str,my @num) = Data::Str2Num->str2float($var->[$i], {ascii_float => 1});
                      if(@num == 1 && @$str == 0) {
                          push @secs_obj, 'N', $num[0];
                      }
@@ -434,6 +431,7 @@ my @bin_format = (
 #
 sub neuterify
 {
+     require Data::SecsPack;
 
      ######
      # This subroutine uses no object data; therefore,
@@ -910,6 +908,7 @@ sub secs_elementify
          }
      }
      else {
+         require Data::SecsPack;
          if ($format =~ /[SUF]\d/ || $format eq 'T' || $format eq 'N') {
              my $number;
              $format = 'I' if $format eq 'N';
@@ -1072,7 +1071,7 @@ sub transify
               # Count the numbers, should agree with length 
               elsif ($format =~ /^[FNSTU]$/)  {
                   if(0 < $length) {
-                       ($str, my @nums) = Data::SecsPack->str2float($ascii_secs, {ascii_float => 1});
+                       ($str, my @nums) = Data::Str2Num->str2float($ascii_secs, {ascii_float => 1});
                        $ascii_secs = join ' ',@$str;
                        if($length != @nums) {
                            $event = "Wrong number of numbers." ;
@@ -1096,7 +1095,7 @@ sub transify
               ######
               # Count the numbers
               if( $format =~ /^[FNSTU]$/ ) {
-                  ($str, my @nums) = Data::SecsPack->str2float($ascii_secs, {ascii_float => 1});
+                  ($str, my @nums) = Data::Str2Num->str2float($ascii_secs, {ascii_float => 1});
                   $ascii_secs = join ' ',@$str;
                   push @secs_obj, "$format$byte_code";
                   if(@nums == 0) {
@@ -1318,7 +1317,7 @@ nested list between machines is SEMI E5-94.
 
 The L<Data::Secs2|Data::Secs2> program module
 facilitates the secsification of the nested data in accordance with 
-L<SEMI|http:E<sol>E<sol>www.semi.org>  E5-94,
+SEMI, http://www.semi.org,  E5-94,
 Semiconductor Equipment Communications Standard 2 (SECS-II),
 pronounced 'sex two' with gussto and a perverted smile. 
 The SEMI E4 SECS-I standard addresses transmitting SECSII messages from one machine to
@@ -1371,7 +1370,7 @@ Tony Blair not only SECS-II but SECS-I and High-Speed SECS.
 
 The nested data linear format used by the
 L<Data::Secs2|Data::Secs2> suroutines is in accordance with 
-L<SEMI|http:E<sol>E<sol>www.semi.org> E5-94,
+SEMI, http://www.semi.org, E5-94,
 Semiconductor Equipment Communications Standard 2 (SECS-II),
 pronounced 'sex two' with gussto and a perverted smile. 
 This industry standard is copyrighted and cannot be
@@ -2855,7 +2854,7 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =item L<Data::SecsPack|Data::SecsPack> 
 
-=item =item L<SEMI|http:E<sol>E<sol>www.semi.org>
+=item SEMI, http://www.semi.org,
 
 =item L<Docs::Site_SVD::Data_Secs2|Docs::Site_SVD::Data_Secs2>
 
