@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.05';
-$DATE = '2004/05/02';
+$VERSION = '0.06';
+$DATE = '2004/05/11';
 $FILE = __FILE__;
 
 ########
@@ -40,7 +40,7 @@ $FILE = __FILE__;
 
  Version: 
 
- Date: 2004/05/02
+ Date: 2004/05/11
 
  Prepared for: General Public 
 
@@ -178,6 +178,11 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  my $test_data6 = [ [78,45,25], [512,1024], 100000 ];
  my $test_data7 = 'a50150010541004105' . unpack('H*','ARRAY') . 
                   'a5034e2d19' .  'a90402000400' . 'b104000186a0';
+ my $test_data17 = 'a50150010541004105' . unpack('H*','ARRAY') . 
+                  'a5034e2d19' .  'a90402000400' . 'b0000186a0';
+ ^
+
+ QC:
  #######
  # multicell numberics, Perl Secs Object
  #
@@ -355,8 +360,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      A[5] ARRAY
      A[4] body
  ';
- my $test_data17 = 'a50150010541004105' . unpack('H*','ARRAY') . 
-                  'a5034e2d19' .  'a90402000400' . 'b0000186a0';
+
  #######
  # multicell numberics, Perl Secs Object
  #
@@ -369,6 +373,17 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
    U2[2] 512 1024
    U4 100000
  ';
+ my $test_data19 =
+ 'U1[1] 80
+ L[7]
+   A[0]
+   A[5] ARRAY
+   N 2
+   A[5] hello
+   N 4
+   N 0
+   L[0]
+ ';
  ^
  VO: ^
   N: UUT loaded as Part of Test::Tech^
@@ -428,8 +443,8 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
 =head2 ok: 6
 
   N: ascii secsify lisfication of test_data1 an array reference^
-  A: secsify( listify( ['2', 'hello', 4] ) )^
-  E: $test_data1^
+  A: secsify( listify( ['2', 'hello', 4, 0, undef] ) )^
+  E: $test_data19^
  ok: 6^
 
 =head2 ok: 7
@@ -939,6 +954,12 @@ my $test_data6 = [ [78,45,25], [512,1024], 100000 ];
 my $test_data7 = 'a50150010541004105' . unpack('H*','ARRAY') . 
                  'a5034e2d19' .  'a90402000400' . 'b104000186a0';
 
+my $test_data17 = 'a50150010541004105' . unpack('H*','ARRAY') . 
+                 'a5034e2d19' .  'a90402000400' . 'b0000186a0';
+^
+
+
+QC:
 #######
 # multicell numberics, Perl Secs Object
 #
@@ -1125,8 +1146,6 @@ L[6]
     A[4] body
 ';
 
-my $test_data17 = 'a50150010541004105' . unpack('H*','ARRAY') . 
-                 'a5034e2d19' .  'a90402000400' . 'b0000186a0';
 
 #######
 # multicell numberics, Perl Secs Object
@@ -1140,6 +1159,18 @@ L[5]
   U2[2] 512 1024
   U4 100000
 ';
+
+my $test_data19 =
+'U1[1] 80
+L[7]
+  A[0]
+  A[5] ARRAY
+  N 2
+  A[5] hello
+  N 4
+  N 0
+  L[0]
+';
 ^
 
 VO: ^
@@ -1192,8 +1223,8 @@ L[6]
 ok: 5^
 
  N: ascii secsify lisfication of test_data1 an array reference^
- A: secsify( listify( ['2', 'hello', 4] ) )^
- E: $test_data1^
+ A: secsify( listify( ['2', 'hello', 4, 0, undef] ) )^
+ E: $test_data19^
 ok: 6^
 
 VO: ^
